Name:           antlrworks
Version:        1.5.2
Release:        4%{?dist}
Summary:        Grammar development environment for ANTLR v3 grammars

Group:          Development/Tools
License:        BSD
URL:            http://www.antlr3.org/works
Source0:        https://github.com/antlr/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}.desktop
# Disable embedding of dependency jars files into antlrworks jar file
Patch0:         %{name}-1.5.2-build.patch
# Fix compilation with JGoodies Forms >= 1.7.1
Patch1:         %{name}-1.5.2-jgoodies-forms_1.7.1.patch
# Add xdg-open to the list of available browsers to open the help
Patch2:         %{name}-1.5.2-browsers.patch

BuildRequires:  ant
BuildRequires:  antlr3-tool >= 3.5
BuildRequires:  desktop-file-utils
BuildRequires:  java-devel >= 1:1.6.0
BuildRequires:  jgoodies-forms >= 1.7.1
BuildRequires:  stringtemplate
BuildRequires:  stringtemplate4
Requires:       antlr3-tool >= 3.5
Requires:       graphviz
# Owns /usr/share/icons/hicolor
Requires:       hicolor-icon-theme
# Antlrworks requires javac
Requires:       java-devel >= 1:1.6.0
Requires:       jgoodies-forms >= 1.7.1
Requires:       stringtemplate4
BuildArch:      noarch

%description
ANTLRWorks is a novel grammar development environment for ANTLR v3 grammars
written by Jean Bovet (with suggested use cases from Terence Parr). It combines
an excellent grammar-aware editor with an interpreter for rapid prototyping and
a language-agnostic debugger for isolating grammar errors. ANTLRWorks helps
eliminate grammar nondeterminisms, one of the most difficult problems for
beginners and experts alike, by highlighting nondeterministic paths in the
syntax diagram associated with a grammar. ANTLRWorks' goal is to make grammars
more accessible to the average programmer, improve maintainability and
readability of grammars by providing excellent grammar navigation and
refactoring tools, and address the most common questions and problems
encountered by grammar developers.


%prep
%setup -q
%patch0 -p0 -b .build
%patch1 -p0 -b .jgoodies-forms_1.7.1
%patch2 -p0 -b .browsers

# Fix version
sed -i "s|^version=.*|version=%{version}|" build.properties

# Add JARs to the default classpath folder
mkdir -p lib/
build-jar-repository -s -p lib/ antlr3-runtime jgoodies-forms stringtemplate stringtemplate4/ST4 


%build
ant build -Daw.lib=lib/ -Dantlr3.jar=antlr3-runtime.jar -Djgoodies.jar=jgoodies-forms.jar


%install
install -Dpm 0644 dist/%{name}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}.jar

%jpackage_script org.antlr.works.IDE "-Xmx400m" "" antlrworks:antlr:antlr3:antlr3-runtime:jgoodies-common:jgoodies-forms:stringtemplate:stringtemplate4 %{name} true

desktop-file-install \
  --dir=$RPM_BUILD_ROOT%{_datadir}/applications \
  %{SOURCE1}

install -Dpm 0644 resources/icons/app.png $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/128x128/apps/%{name}.png
for i in 16 32 64; do
  install -Dpm 0644 resources/icons/app_${i}x$i.png $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/${i}x$i/apps/%{name}.png
done


%check
desktop-file-validate $RPM_BUILD_ROOT%{_datadir}/applications/%{name}.desktop


%post
touch --no-create %{_datadir}/icons/hicolor/ &>/dev/null || :


%postun
if [ $1 -eq 0 ]; then
  touch --no-create %{_datadir}/icons/hicolor/ &>/dev/null
  gtk-update-icon-cache %{_datadir}/icons/hicolor/ &>/dev/null || :
fi


%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor/ &>/dev/null || :


%files
%doc History.txt
%{_bindir}/%{name}
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/*.png
%{_javadir}/*.jar


%changelog
* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.5.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Jul 27 2015 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.5.2-3
- Fix build with latest versions of stringtemplate4

* Tue Jun 16 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Jul 11 2014 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.5.2-1
- Update to 1.5.2

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat May 11 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.4.3-9
- Fix compilation with JGoodies Forms 1.7.1

* Tue Jan 29 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.4.3-8
- Fix compilation with JGoodies Forms 1.6.0 (thanks to Mary Ellen Foster)

* Mon Jan 28 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.4.3-7
- Add missing Requires on antlr-tool (RHBZ #904572), until RHBZ #904979 is fixed

* Sat Jul 21 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.4.3-6
- Add stringtemplate as BuildRequires

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Feb 16 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.4.3-4
- Add missing jgoodies-common jar in wrapper script

* Tue Feb 07 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.4.3-3
- Add version condition on antlr3-tool
- Fix wrapper script generation

* Thu Feb 02 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.4.3-2
- Remove unintended line break

* Thu Feb 02 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.4.3-1
- Update to 1.4.3

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Dec 21 2011 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.4-6
- Add jgoodies-common jar in the launcher classpath
- Fix compilation with JGoodies Common 1.4.2
- Spec cleanup

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Jun 12 2010 Mohamed El Morabity <melmorabity@fedoraproject.org> 1.4-4
- Bump release

* Fri Jun  4 2010 Mohamed El Morabity <melmorabity@fedoraproject.org> 1.4-3
- Remove manual installation of antlrworks.desktop (managed by
  desktop-file-install)

* Thu Jun  3 2010 Mohamed El Morabity <melmorabity@fedoraproject.org> 1.4-2
- Remove release.txt and readme.txt from sources
- Add hicolor-icon-theme as a Requires since it owns
  %%{_datadir}/icons/hicolor
- Add call to desktop-file-install

* Fri May 14 2010 Mohamed El Morabity <melmorabity@fedoraproject.org> 1.4-1
- Initial RPM release
